//
//
// analysis.C
//
// 

#include <iomanip.h>

TFile foutp;

int wavesim(const TString &fname="test")
{

  gROOT->Reset();

  gSystem->Load("libPhysics.so");
  gSystem->Load("../lib/libDOMKernel.so");
  gSystem->Load("../lib/libDOMPMT.so");
    
  TString outname(fname);
  outname += ".root";
  cerr << "outputname = " << outname << endl;

  foutp = new TFile(outname,"RECREATE");

  gStyle->SetOptStat(0);
  gStyle->SetPalette(1);
  gStyle->SetCanvasColor(33);
  gStyle->SetFrameFillColor(18);
  
  // create modules ...
  
  Double_t hv = 2000;

  DOMPMT               *dompmt    = new DOMPMT();  
  DOMPMTPhotoCathode   *cathode   = new DOMPMTPhotoCathode();
  DOMPMTChargeResponce *qresponce = new DOMPMTChargeResponce(hv);
  DOMPMTWaveForm       *waveform  = new DOMPMTWaveForm();

  // add modules...
  
  cathode->SetMother(dompmt);
  dompmt->Add((TTask *)cathode);
  qresponce->SetMother(dompmt);
  dompmt->Add((TTask *)qresponce);
  waveform->SetMother(dompmt);
  dompmt->Add((TTask *)waveform);

  // configure...

  dompmt->ExecuteTask("Configure");

  // process...

  ifstream in("photons.data");
  TVector3 pos, dir;
  TObjArray photonarray(1);

  Int_t evt = 0;
  dompmt->SetCurrentEventNumber(0); 
  while ( in >> pos(0) >> pos(1) >> pos(2) ) {
     cerr << " current evt no = " << evt << endl;
     DOMOpticalPhoton *photon = new DOMOpticalPhoton(pos, dir);
     photonarray.Add(photon);
     photonarray.SetOwner();
     dompmt->SetPhotonArray(&photonarray);
     dompmt->ExecuteTask("Process");
     photonarray.Clear();
     evt ++;
     //if (evt > 10) break;
  }

  // finish...

  dompmt->ExecuteTask("Finish");


  foutp->Write();
}



