#ifndef __DOMPoint__H__
#define __DOMPoint__H__

//*************************************************************************
//* ---------------------
//* DOMPoint Class
//* ---------------------
//* (Description)
//*     Abstract point class  
//* (Requires)
//* (Provides)
//*	DOMPoint              : abstruct point class
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************


#include <TObject.h>
#include <TVector3.h>
#include <iostream>
#include <fstream>

class DOMPoint : public TObject {

public:

  DOMPoint();
  DOMPoint(const TVector3 &pos, const TVector3 &dir, Double_t time = 0);
  virtual ~DOMPoint();


  // pure virtual method
  virtual void Output(ofstream &out); 



  // inline functions
  inline virtual TVector3 GetPosition()  const { return fPosition;  } 
  inline virtual TVector3 GetDirection() const { return fDirection; }
  inline virtual Double_t GetTime()      const { return fTime;      }
  inline virtual void     SetPosition(TVector3 pos)  { fPosition = pos;  } 
  inline virtual void     SetDirection(TVector3 dir) { fDirection = dir; }
  inline virtual void     SetTime(Double_t t)        { fTime = t;        }
  inline virtual void     AppendTime(Double_t dt)    { fTime += dt;      }

  inline virtual Bool_t   IsValid() const      { return fValidity;    }
  inline virtual void     Invalidate()         { fValidity = kFALSE;  }
  inline virtual void     Validate()           { fValidity = kTRUE;   }

private:

  Bool_t    fValidity;      // 0=kFALSE, 1=kTRUE;
  TVector3  fPosition;      // position of the point
  TVector3  fDirection;     // direction of the velocity of the point
  Double_t  fTime;          // time stamp of the point

  ClassDef(DOMPoint, 1)    // abstract point class

};

#endif

