#ifndef __DOMVModule__H__
#define __DOMVModule__H__

//*************************************************************************
//* ---------------------
//* DOMVModule Class
//* ---------------------
//* (Description)
//*     Abstract module class for modules.
//* (Requires)
//* (Provides)
//*	DOMVModule              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************


#include <TROOT.h>
#include <TSystem.h>
#include <TChain.h>
#include <TTree.h>
#include <TBrowser.h>
#include <TClonesArray.h>
#include <TApplication.h>
#include <TFile.h>
#include <TKey.h>
#include <TString.h>
#include <TTask.h>
#include <iostream>
#include <fstream>

#include "DOMTypeDef.h"

using namespace std;

class DOMVModule : public TTask {

public:

  DOMVModule():TTask(){}
  DOMVModule(const Char_t *name, const Char_t *title);
  DOMVModule(DOMVModule *mother, const Char_t *name, const Char_t *title);

  virtual ~DOMVModule();

  virtual void    Configure() = 0;
  virtual void    Process()   = 0;
  virtual void    Finish()    = 0;
  virtual void    Exec(Option_t *opt);
 
  static  Int_t   GetCurrentEventNumber()        { return fgCurEventNo;    }
  static  Int_t   GetMaxNumberOfEvents()         { return fgNEvents;       }
  static  EState  CurrentState()                 { return fgState;         }
  inline  TString GetInputFileName()             { return fInputFileName;  } 
  inline  TString GetOutputFileName()            { return fOutputFileName; }

  inline  virtual DOMVModule*  GetMother() const  { return fMother;        }
  inline  virtual EIOStyle     GetIOStyle() const { return fIOStyle;       }

  static  void    SetCurrentEventNumber(Int_t n) { fgCurEventNo = n;       }
  static  void    SetMaxNumberOfEvents(Int_t n)  { fgNEvents = n;          }
  static  void    ChangeState(EState st=kAlive)  { fgState = st;           }
  inline  void    SetInputFileName(TString ifn)  { fInputFileName = ifn;   } 
  inline  void    SetOutputFileName(TString ofn) { fOutputFileName = ofn;  }

  inline  virtual void  SetMother(DOMVModule *m) { fMother = m;            }
  inline  virtual void  SetIOStyle(EIOStyle s)   { fIOStyle = s;           }
  
protected:

  ifstream  *fIfs;                   //! input file stream 
  ofstream  *fOfs;                   //! output file stream
  
private:

  static EState   fgState;            // state of simulated particle 
  static Int_t    fgNEvents;          // max number of events 
  static Int_t    fgCurEventNo;       // current event number

  EIOStyle        fIOStyle;          // state of simulated particle 
  TString         fInputFileName;    // input file name
  TString         fOutputFileName;   // output file name
  DOMVModule     *fMother;           // pointer to its mother DOMVModule;

  ClassDef(DOMVModule, 1)            // abstract base class for modules

};

#endif

