#ifndef __DOMPMT__H__
#define __DOMPMT__H__

//*************************************************************************
//* ---------------------
//* DOMPMT Class
//* ---------------------
//* (Description)
//*     Abstract module class for imput data.
//* (Requires)
//* (Provides)
//*	DOMPMT              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************

#include <TF1.h>
#include <TObjArray.h>
#include "DOMVModule.h"

class DOMPMT : public DOMVModule {

public:

  DOMPMT(const Char_t *name = "DOMPMT", 
         const Char_t *title = "DOM PMT module");
  virtual ~DOMPMT();

  virtual void Configure() ;
  virtual void Process()   ;
  virtual void Finish()    ;

  inline const TObjArray &GetPhotoElectronArray() const { return *fPEArray;        }
  inline const TObjArray &GetPhotonArray()        const { return *fPhotonArray;    }
  inline const TObjArray &GetSinglePEChargeArray()const { return *fSPEGainArray;   }
  inline const TF1       &GetChargeResponce()     const { return *fChargeResponce; }
  inline virtual void     SetPhotoElectronArray(TObjArray *ar) { fPEArray = ar;    }
  inline virtual void     SetPhotonArray       (TObjArray *ar) { fPhotonArray = ar;}
  inline virtual void     SetSinglePEChargeArray (TObjArray *ar) { fSPEGainArray = ar;}
  inline virtual void     SetChargeResponce(TF1 *f)     { fChargeResponce = f;     }
  
private:

  TString    fPhotoCathodeOutput; // output filename for photocathode 
  TString    fWaveformOutput;     // output filename for waveform

  TObjArray *fPhotonArray;        // pointer to the photon array
  TObjArray *fPEArray;            // pointer to the p.e array
  TObjArray *fSPEGainArray;       // pointer to the p.e array
  TF1       *fChargeResponce;     // pointer to the charge responce function

  ClassDef(DOMPMT, 1)             // abstract base class for modules

};

#endif

