//*************************************************************************
//* --------------------
//* DOMPMTChargeResponce
//* --------------------
//* (Description)
//*	Abstract base class for DOM modules.
//* (Requires)
//* (Provides)
//* (Update Record)
//*	2003/12/22  K.Hoshina	Original version.
//*************************************************************************

#include "DOMPMTChargeResponce.h"
#include "DOMPMTPEChargeDatum.h"
#include "DOMPMT.h"

#include <iostream>
#include <fstream>

ClassImp(DOMPMTChargeResponce)

using namespace std;

// TMP_TREATMENT!!!
// gain curve possibly deviate among individual PMTs!

const Double_t DOMPMTChargeResponce::fgkQt_ov_Q0  =  3.69343e-01; // qtau / q0
const Double_t DOMPMTChargeResponce::fgkSQ0_ov_Q0 =  2.87084e-01; // sq0 / q0
const Double_t DOMPMTChargeResponce::fgkPe        =  2.68070e-01; // pe 
const Double_t DOMPMTChargeResponce::fgkP0        =  4.39448e-10; // gain_func, P0
const Double_t DOMPMTChargeResponce::fgkP1        = -5.75542e-13; // gain_func, P1
const Double_t DOMPMTChargeResponce::fgkP2        =  1.92296e-16; // gain_func, P2

// global function

//================================================================
// function ChargeResponce1pe_noconv
//================================================================

Double_t ChargeResponce1pe_noconv(Double_t *x, Double_t *par) { 

   Double_t q0      = par[0];               // mean of gaussian term

   // scale sq0 and qtau
   Double_t sq0     = par[1] * q0; 
   Double_t qtau    = par[2] * q0; 
   Double_t pe      = par[3];
   Double_t dq0     = x[0];

   Double_t normalizelim  = - q0/sq0;
   Double_t normarize     = 0.5 * TMath::Erfc(normalizelim);

   Double_t sigexpo = pe / qtau  
                         * TMath::Exp(- dq0 / qtau);

   Double_t sum2sigma0 = sq0 * sq0;
   Double_t siggaus    = (1.- pe) * TMath::Exp(-0.5 *(dq0 - q0) * (dq0 - q0) / sum2sigma0)
                               / (TMath::Sqrt(2 * TMath::Pi() * sum2sigma0) * normarize);

   Double_t signal     = sigexpo + siggaus;

   return   signal; 

}




//=====================================================================
//* constructor -------------------------------------------------------

DOMPMTChargeResponce::DOMPMTChargeResponce(Double_t hv,
                                           const TString &calibfile, 
                                           const Char_t  *name, 
                                           const Char_t  *title)
                   : DOMVModule(name,title), fCalibfileName(calibfile),
                     fPEArray(0), fChargeResponce(0), fChargeHist(0), 
                     fCanvas(0), fCanvas2(0)
{
   SetHV(hv);
   SetIOStyle(kDirectConnect);
}

//=====================================================================
//* destructor --------------------------------------------------------

DOMPMTChargeResponce::~DOMPMTChargeResponce()
{
   if (fPEArray)        delete fPEArray;
   if (fChargeResponce) delete fChargeResponce;
   if (fChargeHist)       delete fChargeHist;
   if (fCanvas)         delete fCanvas;
}

//=====================================================================
//* GetCharge -----------------------------------------------------------

Double_t DOMPMTChargeResponce::GetCharge(Double_t hv) 
{
   fGain = fgkP0 + fgkP1 * hv + fgkP2 * hv * hv; 
   cerr << "DOMPMTChargeResponce:: HV, current charge = " 
        << hv << " " << fGain << endl;
   return fGain; 
}

//===================================================================
//* Configure ---------------------------------------------------------

void DOMPMTChargeResponce::Configure()
{

   CreateSinglePEChargeResponce(); 

}

//=====================================================================
//* Process -----------------------------------------------------------

void DOMPMTChargeResponce::Process()
{
   cerr << "DOMPMTChargeResponce::Process is called! " << endl;

   // delete remaining arrays
   if (fPEArray) fPEArray->Clear();
   fSinglePEChargeArray.Clear();


   //
   // read photo electrons 
   //

   if (GetIOStyle() == kASCII) {
      // input file open

   } else if (GetIOStyle() == kDirectConnect) {

      fPEArray = new TObjArray(((DOMPMT *)GetMother())->GetPhotoElectronArray());

   }  

   //
   // create charge responce
   //

   if (fPEArray->GetEntries() == 1) {
      // single p.e event!
            
      DOMPhotoElectron *pe = dynamic_cast<DOMPhotoElectron*>(fPEArray->First()); 
      // TMP_TREATMENT!!! gain is possibly depend on the position!

      Double_t gain = fChargeResponce->GetRandom();
      DOMPMTPEChargeDatum *datum = new DOMPMTPEChargeDatum(gain, 0);
      fSinglePEChargeArray.Add(datum);
      fChargeHist->Fill(gain);
      
      cerr << " DOMPMTChargeResponce::Process: gain value = " << gain << endl;

   } else if (fPEArray->GetEntries() > 1) {

      cerr << "DOMPMTChargeResponce::Process: "
           << "Sorry, multi pe charge responce is not yet implimented!" << endl; 

   } else {

      cerr << "DOMPMTChargeResponce::Process: "
           << "No pe!!!" << endl;

   }
   fSinglePEChargeArray.SetOwner();
   ((DOMPMT *)GetMother())->SetSinglePEChargeArray(&fSinglePEChargeArray);

   
}

//=====================================================================
//* Finish ------------------------------------------------------------

void DOMPMTChargeResponce::Finish()
{
   fCanvas = new TCanvas("SinglePEChargeResponce", "Charge Responce of single P.E",
                          10, 10, 800, 400);
   fCanvas2 = new TCanvas("SinglePEChargeResponce2", "gained charge of single PE",
                          10, 10, 400, 400);
   fCanvas->Divide(2, 1);
   fCanvas->cd(1);
   fChargeResponce->Draw();
   fCanvas->cd(2);
   fChargeResponce->DrawIntegral();
   fCanvas2->cd();
   fChargeHist->Draw();
}

//=====================================================================
//* CreateSiglePeChargeResponce -----------------------------------------

void DOMPMTChargeResponce::CreateSinglePEChargeResponce()
{
   cerr << "DOMPMTChargeResponce::CalcSinglePEChargeResponce is called!" << endl;  
   Double_t par[4];
   par[0] = fGain;
   par[1] = fgkSQ0_ov_Q0; 
   par[2] = fgkQt_ov_Q0; 
   par[3] = fgkPe; 

   Int_t    nbins = 5000;
   Double_t xmax  = fGain * 3.;

   fChargeResponce = new TF1("SinglePEChargeResponce", ChargeResponce1pe_noconv,
                              0, xmax, 4);
   fChargeResponce->SetLineWidth(4);
   fChargeResponce->SetLineColor(kRed);
   fChargeResponce->SetNpx(nbins);
   fChargeResponce->SetParameters(par);

   fChargeHist = new TH1D("GainedCharge", "Gained charge", nbins, 0, xmax); 
   
}


