#ifndef __DOMPMTChargeResponce__H__
#define __DOMPMTChargeResponce__H__

//*************************************************************************
//* ---------------------
//* DOMPMTChargeResponce Class
//* ---------------------
//* (Description)
//*     Abstract module class for imput data.
//* (Requires)
//* (Provides)
//*	DOMPMTChargeResponce              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************

#include "DOMVModule.h"
#include "DOMPhotoElectron.h"
#include <TF1.h>
#include <TH1D.h>
#include <TCanvas.h>
#include <TVector3.h>

class DOMPMTChargeResponce : public DOMVModule {

public:

  DOMPMTChargeResponce(Double_t        hv,
                       const TString  &calibfile = "SF0077calib.dat",
                       const Char_t   *name      = "DOMPMTChargeResponce", 
                       const Char_t   *title     = "Photon to p.e. simulator");

  virtual ~DOMPMTChargeResponce();

  virtual void Configure();
  virtual void Process();
  virtual void Finish();
 
  virtual Double_t GetCharge(Double_t hv); 

  inline virtual Double_t GetHV() const    { return fHV;  }
  inline virtual void     SetHV(Double_t hv) 
                          { 
                              fHV = hv;  
                              fGain = GetCharge(hv);
                          }
  
private:

  void CreateSinglePEChargeResponce();

private:

  static const Double_t fgkQt_ov_Q0;   //  qtau / q0
  static const Double_t fgkSQ0_ov_Q0;  //  sq0 / q0 
  static const Double_t fgkPe;         //  pe
  static const Double_t fgkP0;         // gain_func, P0
  static const Double_t fgkP1;         // gain_func, P1
  static const Double_t fgkP2;         // gain_func, P2


  Double_t   fHV  ;                    // value of high voltage
  Double_t   fGain;                    // gain at center of PMT
  TString    fCalibfileName;           // filename of calibration

  TObjArray *fPEArray;                 // Input Photo electron array
  TF1       *fChargeResponce;          // Function of charge responce 
  TObjArray  fSinglePEChargeArray;     // Output gain array
  TH1D      *fChargeHist;              // gained charge hist
  TCanvas   *fCanvas;                  // Canvas for QResponce
  TCanvas   *fCanvas2;                 // Canvas for QResponce

  ClassDef(DOMPMTChargeResponce, 1)    // abstract base class for modules

};

#endif

