#ifndef __DOMPMTPhotoCathode__H__
#define __DOMPMTPhotoCathode__H__

//*************************************************************************
//* ---------------------
//* DOMPMTPhotoCathode Class
//* ---------------------
//* (Description)
//*     Abstract module class for imput data.
//* (Requires)
//* (Provides)
//*	DOMPMTPhotoCathode              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************

#include <TVector3.h>
#include <TH2D.h>
#include <TCanvas.h>
#include "DOMVModule.h"


class DOMPMTPhotoCathode : public DOMVModule {

public:

  DOMPMTPhotoCathode(const TString &uniformity = "uniformity_default.data",
                     const Char_t  *name  = "DOMPMTPhotoCathode", 
                     const Char_t  *title = "Photon to p.e. simulator");

#if 0
  DOMPMTPhotoCathode(TH2D  unif_hist,
                     const Char_t  *name="DOMPMTPhotoCathode", 
                     const Char_t  *title="Photon to p.e. simulator");
#endif

  virtual ~DOMPMTPhotoCathode();

  virtual void Configure();
  virtual void Process();
  virtual void Finish();
  
private:

  void     CreateUniformityMap();
  //Double_t GetZenithPosition(TVector3 gp);
  //Double_t GetAzimuthPhi(TVector3 gp);
  Double_t GetXPosition(TVector3 gp);
  Double_t GetYPosition(TVector3 gp);

private:

  static const Int_t    fgkNXbins;    // No of Xbins of UniformityMap
  static const Int_t    fgkNYbins;    // No of Ybins of UniformityMap 
  static const Double_t fgkXmin;      // min of X-axis of UniformityMap
  static const Double_t fgkXmax;      // max of X-axis of UniformityMap
  static const Double_t fgkYmin;      // min of Y-axis of UniformityMap
  static const Double_t fgkYmax;      // max of Y-axis of UniformityMap

  TH2D      *fUniformityMap;        // 2D histgram of uniformity 
  TH2D      *fPEMap;                // 2D histgram of photo electrons
  TObjArray *fPhotonArray;          // Array of arrival photons
  TObjArray  fPEArray;              // Array of photo electrons
  Double_t   fAbsoluteQE;           // Absolute QE 
  TString    fUniformityData;       // filename of uniformity data
  TCanvas   *fCanvas;               // canvas for histgrams

  ClassDef(DOMPMTPhotoCathode, 1)   // abstract base class for modules

};

#endif

