#ifndef __DOMPMTWaveForm__H__
#define __DOMPMTWaveForm__H__

//*************************************************************************
//* ---------------------
//* DOMPMTWaveForm Class
//* ---------------------
//* (Description)
//*     Abstract module class for imput data.
//* (Requires)
//* (Provides)
//*	DOMPMTWaveForm              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************

#include "DOMVModule.h"
#include "DOMPhotoElectron.h"
#include <TF1.h>
#include <TH1D.h>
#include <TCanvas.h>
#include <TVector3.h>

class DOMPMTWaveForm : public DOMVModule {

public:

  DOMPMTWaveForm( const Char_t   *name  = "DOMPMTWaveForm", 
                  const Char_t   *title = "Wave form simulator");

  virtual ~DOMPMTWaveForm();

  virtual void Configure();
  virtual void Process();
  virtual void Finish();
 
private:

  Double_t GetNormalization(Double_t charge);

private:

  static const Double_t fgkSigma;      // sigma of pulse
  static const Double_t fgkTerminator; // sigma of pulse
  static const Double_t fgkT0;         // sigma of pulse
  static const Double_t fgkGround;     // sigma of pulse
  static const Double_t fgkBinMax;     // sigma of pulse

  TObjArray *fSinglePEChargeArray;  // input charge array
  TF1       *fWaveForm;             // simulated gain
  TObjArray  fWaveFormArray;        // simulated gain
  TH1D      *fNormHist;              // simulated gain
  TCanvas   *fCanvas;               // Canvas for QResponce
  TCanvas   *fCanvas1;              // Canvas for QResponce

  ClassDef(DOMPMTWaveForm, 1)   // abstract base class for modules

};

#endif

